@@ -113,7 +113,7 @@ h5writeDataset <- function(obj, h5loc, name, ...) {
     invisible(res)
 }
 
-h5writeDataset.data.frame <- function(obj, h5loc, name, level=7, chunk, DataFrameAsCompound = TRUE) {
+h5writeDataset.data.frame <- function(obj, h5loc, name, level=6, chunk, DataFrameAsCompound = TRUE) {
     if (DataFrameAsCompound) {
         if (H5Lexists(h5loc, name)) {
             stop("Cannot write data.frame. Object already exists. Subsetting for compound datatype not supported.")
@@ -140,6 +140,7 @@ h5writeDataset.data.frame <- function(obj, h5loc, name, level=7, chunk, DataFram
         ## we can't write out factors, so convert any to character
         colClass <- sapply(obj, is.factor)
         if(any(colClass)) {
+            #obj[,which(colClass)] <- as.character(obj[,which(colClass)])
             obj[ which(colClass) ] <- lapply(obj[ ,which(colClass), drop=FALSE], FUN = as.character)
         }
         
@@ -148,7 +149,7 @@ h5writeDataset.data.frame <- function(obj, h5loc, name, level=7, chunk, DataFram
     invisible(res)
 }
 
-h5writeDataset.list <- function(obj, h5loc, name, level=7) {
+h5writeDataset.list <- function(obj, h5loc, name, level=6) {
     exists <- try( { H5Lexists(h5loc, name) } )
     if (exists) {
         message("Existing object within HDF5 file cannot be overwritten with a list object. First delete the group or dataset from the HDF5 file.")
@@ -180,13 +181,14 @@ h5writeDataset.list <- function(obj, h5loc, name, level=7) {
     }
 }
 
-h5writeDataset.matrix <- function(...) { h5writeDataset.array(...) }
-h5writeDataset.integer <- function(...) { h5writeDataset.array(...) }
-h5writeDataset.double <- function(...) { h5writeDataset.array(...) }
-h5writeDataset.logical <- function(...) { h5writeDataset.array(...) }
+h5writeDataset.matrix    <- function(...) { h5writeDataset.array(...) }
+h5writeDataset.integer   <- function(...) { h5writeDataset.array(...) }
+h5writeDataset.double    <- function(...) { h5writeDataset.array(...) }
+h5writeDataset.logical   <- function(...) { h5writeDataset.array(...) }
 h5writeDataset.character <- function(...) { h5writeDataset.array(...) }
+h5writeDataset.raw       <- function(...) { h5writeDataset.array(...) }
 
-h5writeDataset.array <- function(obj, h5loc, name, index = NULL, start=NULL, stride=NULL, block=NULL, count=NULL, size=NULL, level=7) {
+h5writeDataset.array <- function(obj, h5loc, name, index = NULL, start=NULL, stride=NULL, block=NULL, count=NULL, size=NULL, level=6) {
 
     exists <- try( { H5Lexists(h5loc, name) } )
     if (!exists) {
@@ -194,9 +196,11 @@ h5writeDataset.array <- function(obj, h5loc, name, index = NULL, start=NULL, str
             size = NULL
             if (storage.mode(obj) == "character") {
                 if (length(obj) > 0) {
-                    size <- max(nchar(obj), na.rm = TRUE)+1
-                    ## if any NA, the minimum string length is 3
-                    if(any(is.na(obj)) && size < 3) { size <- 3 }
+                    size <- max(nchar(obj), na.rm = TRUE)
+                    ## if any NA, the minimum string length is 2
+                    if(any(is.na(obj)) && size < 2) { size <- 2 }
+                    ## empty string gives size 0, and errors
+                    if(size == 0) { size <- 1 }
                 } else {
                     size <- 1
                 }
