@@ -126,132 +126,6 @@ SEXP _H5Dget_storage_size( SEXP _dataset_id ) {
     return Rval;
 }
 
-void getMemSpaceDim( hid_t file_space_id, hsize_t *size) {
-    hssize_t sel_hyper_nblocks = H5Sget_select_hyper_nblocks( file_space_id );
-    int rank = H5Sget_simple_extent_ndims( file_space_id );
-    hsize_t sizebuf[2*rank*sel_hyper_nblocks];
-    H5Sget_select_hyper_blocklist(file_space_id, 0, sel_hyper_nblocks, sizebuf );
-    
-    int isnew;
-    for (int i=0; i < rank; i++) {
-        size[i] = 0;
-        for (int j=0; j < sel_hyper_nblocks; j++) {
-            isnew = 1;
-            for (int k=0; k < j; k++) {
-                if ((sizebuf[j*2*rank+i] == sizebuf[k*2*rank+i]) 
-                        & (sizebuf[j*2*rank+i+rank] == sizebuf[k*2*rank+i+rank])) {
-                    isnew=0;
-                }
-            }
-            if (isnew != 0) {
-                size[i] += (sizebuf[j*2*rank+i+rank] - sizebuf[j*2*rank+i] + 1);
-            }
-        }
-    }
-}
-
-SEXP _create_Integer_test_file() {
-    /* long long x[17]; */
-    /* unsigned long long y[11]; */
-    
-    /* y[0] = ULONG_MAX; */
-    /* y[1] = LLONG_MAX; */
-    /* y[1] = y[1] + 1; */
-    /* y[2] = LLONG_MAX; */
-    /* y[3] = 0x0020000000000000UL; */
-    /* y[4] = 0x001fffffffffffffUL; */
-    /* y[5] = UINT_MAX; */
-    /* y[5] = y[5] + 1; */
-    /* y[6] = UINT_MAX; */
-    /* y[7] = INT_MAX; */
-    /* y[7] = y[7] + 1; */
-    /* y[8] = INT_MAX; */
-    /* y[9] = 1; */
-    /* y[10] = 0; */
-    
-    /* printf("\n"); */
-    /* for (int i=0; i<11; i++) { */
-    /*   printf("y[%d] = %llu\n",i, y[i]); */
-    /* } */
-    /* printf("\n"); */
-    
-    /* x[0] = LLONG_MAX; */
-    /* x[1] = 0x0020000000000000L; */
-    /* x[2] = 0x001fffffffffffffL; */
-    /* x[3] = UINT_MAX; */
-    /* x[3] = x[3] + 1; */
-    /* x[4] = UINT_MAX; */
-    /* x[5] = INT_MAX; */
-    /* x[5] = x[5] + 1; */
-    /* x[6] = INT_MAX; */
-    /* x[7] = 1; */
-    /* x[8] = 0; */
-    /* x[9] = -1; */
-    /* x[10] = INT_MIN+1; */
-    /* x[11] = INT_MIN; */
-    /* x[12] = INT_MIN; */
-    /* x[12] = x[12]-1; */
-    /* x[13] = 0xffe0000000000001L; */
-    /* x[14] = 0xffe0000000000000L; */
-    /* x[15] = LLONG_MIN+1; */
-    /* x[16] = LLONG_MIN; */
-    
-    /* for (int i=0; i<17; i++) { */
-    /*   printf("x[%d] = %ld\n",i, x[i]); */
-    /* } */
-    /* printf("\n"); */
-    
-    /* hid_t fid = H5Fcreate("integer_test.h5",H5F_ACC_TRUNC,H5P_DEFAULT,H5P_DEFAULT); */
-    /* int rank = 1; */
-    /* hsize_t current_dims[1]; */
-    /* current_dims[0] = 17; */
-    /* hid_t sid = H5Screate_simple( rank, &current_dims, &current_dims ); */
-    /* hid_t did; */
-    /* herr_t herr; */
-    
-    /* did = H5Dcreate( fid, "I8", H5T_STD_I8LE, sid, H5P_DEFAULT, H5P_DEFAULT, H5P_DEFAULT ); */
-    /* herr = H5Dwrite( did, H5T_NATIVE_LLONG, sid, sid,H5P_DEFAULT, &x ); */
-    /* H5Dclose(did); */
-    
-    /* did = H5Dcreate( fid, "I16", H5T_STD_I16LE, sid, H5P_DEFAULT, H5P_DEFAULT, H5P_DEFAULT ); */
-    /* herr = H5Dwrite( did, H5T_NATIVE_LLONG, sid, sid,H5P_DEFAULT, &x ); */
-    /* H5Dclose(did); */
-    
-    /* did = H5Dcreate( fid, "I32", H5T_STD_I32LE, sid, H5P_DEFAULT, H5P_DEFAULT, H5P_DEFAULT ); */
-    /* herr = H5Dwrite( did, H5T_NATIVE_LLONG, sid, sid,H5P_DEFAULT, &x ); */
-    /* H5Dclose(did); */
-    
-    /* did = H5Dcreate( fid, "I64", H5T_STD_I64LE, sid, H5P_DEFAULT, H5P_DEFAULT, H5P_DEFAULT ); */
-    /* herr = H5Dwrite( did, H5T_NATIVE_LLONG, sid, sid,H5P_DEFAULT, &x ); */
-    /* H5Dclose(did); */
-    
-    /* H5Sclose(sid); */
-    /* current_dims[0] = 11; */
-    /* sid = H5Screate_simple( rank, &current_dims, &current_dims ); */
-    
-    /* did = H5Dcreate( fid, "U8", H5T_STD_U8LE, sid, H5P_DEFAULT, H5P_DEFAULT, H5P_DEFAULT ); */
-    /* herr = H5Dwrite( did, H5T_NATIVE_ULLONG, sid, sid,H5P_DEFAULT, &y ); */
-    /* H5Dclose(did); */
-    
-    /* did = H5Dcreate( fid, "U16", H5T_STD_U16LE, sid, H5P_DEFAULT, H5P_DEFAULT, H5P_DEFAULT ); */
-    /* herr = H5Dwrite( did, H5T_NATIVE_ULLONG, sid, sid,H5P_DEFAULT, &y ); */
-    /* H5Dclose(did); */
-    
-    /* did = H5Dcreate( fid, "U32", H5T_STD_U32LE, sid, H5P_DEFAULT, H5P_DEFAULT, H5P_DEFAULT ); */
-    /* herr = H5Dwrite( did, H5T_NATIVE_ULLONG, sid, sid,H5P_DEFAULT, &y ); */
-    /* H5Dclose(did); */
-    
-    /* did = H5Dcreate( fid, "U64", H5T_STD_U64LE, sid, H5P_DEFAULT, H5P_DEFAULT, H5P_DEFAULT ); */
-    /* herr = H5Dwrite( did, H5T_NATIVE_ULLONG, sid, sid,H5P_DEFAULT, &y ); */
-    /* H5Dclose(did); */
-    
-    /* H5Sclose(sid); */
-    /* H5Fclose(fid); */
-    
-    SEXP Rval = R_NilValue;
-    return Rval;
-}
-
 SEXP H5Dread_helper_INTEGER(hid_t dataset_id, hid_t file_space_id, hid_t mem_space_id, hsize_t n, SEXP Rdim, SEXP _buf, 
                             hid_t dtype_id, hid_t cpdType, int cpdNField, char ** cpdField, int compoundAsDataFrame,
                             int bit64conversion, int native ) {
@@ -265,7 +139,45 @@ SEXP H5Dread_helper_INTEGER(hid_t dataset_id, hid_t file_space_id, hid_t mem_spa
     int warn = 0;
     int warn_double = 0;
     
-    if ((b < 4) | ((b == 4) & (sgn == H5T_SGN_2))) {   // Read directly to R-integer without loss of data (short or signed int)
+    /* 1-byte integers. Reading strategy is dependent on whether these 
+     * are signed or unsigned (RAWSXP vs INTSXP) */
+    if(b == 1) {
+      void * buf;
+      if(sgn == H5T_SGN_NONE) {
+        
+        mem_type_id = H5T_NATIVE_UCHAR;
+        if (length(_buf) == 0) {
+          Rval = PROTECT(allocVector(RAWSXP, n));
+          buf = RAW(Rval);
+        } else {
+          buf = RAW(_buf);
+          Rval = _buf;
+        }
+        herr_t herr = H5Dread(dataset_id, mem_type_id, mem_space_id, file_space_id, H5P_DEFAULT, buf );
+        if (native)
+          PERMUTE(Rval, RAW, mem_space_id);
+        
+      } else {
+        
+        mem_type_id = H5T_NATIVE_INT32;
+        if (length(_buf) == 0) {
+          Rval = PROTECT(allocVector(INTSXP, n));
+          buf = INTEGER(Rval);
+        } else {
+          buf = INTEGER(_buf);
+          Rval = _buf;
+        }
+        herr_t herr = H5Dread(dataset_id, mem_type_id, mem_space_id, file_space_id, H5P_DEFAULT, buf );
+        if (native)
+          PERMUTE(Rval, INTEGER, mem_space_id);
+        
+      }
+      if (length(_buf) == 0) {
+        setAttrib(Rval, R_DimSymbol, Rdim);
+      }
+      
+    } else {
+    if ( ((b >= 2) & (b < 4)) | ((b == 4) & (sgn == H5T_SGN_2))) {   // Read directly to R-integer without loss of data (short or signed int)
         if (cpdType < 0) {
             mem_type_id = H5T_NATIVE_INT32;
         } else {
@@ -462,6 +374,7 @@ SEXP H5Dread_helper_INTEGER(hid_t dataset_id, hid_t file_space_id, hid_t mem_spa
             setAttrib(Rval, R_DimSymbol, Rdim);
         }
     }
+    }
     
     if ((warn > 0) | (warn_NA > 0) | (warn_double > 0)) {
         if (warn > 0) {
@@ -528,17 +441,19 @@ SEXP H5Dread_helper_FLOAT(hid_t dataset_id, hid_t file_space_id, hid_t mem_space
 SEXP H5Dread_helper_STRING(hid_t dataset_id, hid_t file_space_id, hid_t mem_space_id, hsize_t n, SEXP Rdim, SEXP _buf, 
                            hid_t dtype_id, hid_t cpdType, int cpdNField, char ** cpdField, int compoundAsDataFrame, int native ) {
     hid_t mem_type_id = -1;
-    
+  
+    herr_t status;
     SEXP Rval;
+    
     size_t size = H5Tget_size(dtype_id);
     if (cpdType < 0) {
         mem_type_id = dtype_id;
     } else {
         mem_type_id = H5Tcreate(H5T_COMPOUND, size);
-        herr_t status = H5Tinsert(mem_type_id, cpdField[0], 0, dtype_id);
+        status = H5Tinsert(mem_type_id, cpdField[0], 0, dtype_id);
         for (int i=1; i<cpdNField; i++) {
             hid_t mem_type_id2 = H5Tcreate(H5T_COMPOUND, size);
-            herr_t status = H5Tinsert(mem_type_id2, cpdField[i], 0, mem_type_id);
+            status = H5Tinsert(mem_type_id2, cpdField[i], 0, mem_type_id);
             mem_type_id = mem_type_id2;
         }
     }
@@ -546,22 +461,25 @@ SEXP H5Dread_helper_STRING(hid_t dataset_id, hid_t file_space_id, hid_t mem_spac
 
     if(n > 0) { /* return empty vector if length == 0 */
       if (H5Tis_variable_str(dtype_id)) {
-          char *bufSTR[n];
-          herr_t herr = H5Dread(dataset_id, mem_type_id, mem_space_id, file_space_id, H5P_DEFAULT, bufSTR );
-          if(herr < 0) {
+          char **bufSTR = (char **) R_alloc(n, sizeof(char *));
+          status = H5Dread(dataset_id, mem_type_id, mem_space_id, file_space_id, H5P_DEFAULT, bufSTR );
+          if(status < 0) {
             error("Unable to read dataset");
           }
           for (int i=0; i<n; i++) {
               SET_STRING_ELT(Rval, i, mkChar(bufSTR[i]));
-              free(bufSTR[i]);
+          }
+          status = H5Dvlen_reclaim(mem_type_id, file_space_id, H5P_DEFAULT, bufSTR);
+          if(status < 0) {
+              error("Unable to reclaim variable length buffer\n");
           }
       } else {
           void* bufSTR = R_alloc(n * size, sizeof(char));
           if (bufSTR == 0) {
               error("Not enough memory to read data! Try to read a subset of data by specifying the index or count parameter.");
           }
-          herr_t herr = H5Dread(dataset_id, mem_type_id, mem_space_id, file_space_id, H5P_DEFAULT, bufSTR );
-          if(herr < 0) { 
+          status = H5Dread(dataset_id, mem_type_id, mem_space_id, file_space_id, H5P_DEFAULT, bufSTR );
+          if(status < 0) { 
             error("Unable to read dataset");
           }
           char* bufSTR2 = R_alloc(size + 1, sizeof(char));
@@ -916,6 +834,8 @@ SEXP H5Dread_helper(hid_t dataset_id, hid_t file_space_id, hid_t mem_space_id, h
     } break;
     }
     
+    herr_t status = H5Tclose(dtype_id);
+    
     return(Rval);
 }
 
@@ -988,7 +908,7 @@ SEXP _H5Dread( SEXP _dataset_id, SEXP _file_space_id, SEXP _mem_space_id, SEXP _
     int protect_bool = 0;
     
     if( rank == 0 ) {
-    /* scalar with no dimentsions */
+    /* scalar with no dimensions */
         Rdim = NULL_USER_OBJECT;
     } else if( dtypeclass_id == H5T_ENUM && rank == 0 ) {
     /* do all ENUM have rank 0? */ 
@@ -1059,6 +979,12 @@ SEXP _H5Dwrite( SEXP _dataset_id, SEXP _buf, SEXP _file_space_id, SEXP _mem_spac
     hid_t dim_space_id = mem_space_id == H5S_ALL ? dataset_id : mem_space_id;
     
     switch(TYPEOF(_buf)) {
+    case RAWSXP :
+        mem_type_id = H5T_NATIVE_UCHAR;
+        if (native)
+            PERMUTE(_buf, RAW, dim_space_id);
+        buf = RAW(_buf);
+        break;
     case INTSXP :
         mem_type_id = H5T_NATIVE_INT;
         if (native)
@@ -1072,6 +998,7 @@ SEXP _H5Dwrite( SEXP _dataset_id, SEXP _buf, SEXP _file_space_id, SEXP _mem_spac
         buf = REAL(_buf);
         break;
     case LGLSXP :
+        /* R logical is 32-bit, so this must stay as NATIVE_INT */
         mem_type_id = H5T_NATIVE_INT;
         if (native)
             PERMUTE(_buf, LOGICAL, dim_space_id);
@@ -1081,14 +1008,13 @@ SEXP _H5Dwrite( SEXP _dataset_id, SEXP _buf, SEXP _file_space_id, SEXP _mem_spac
         mem_type_id = H5Dget_type(dataset_id);
         if (native)
             PERMUTE(_buf, STRING_PTR, dim_space_id);
-        
         /* prepare for hdf5 */
         size_t stsize = H5Tget_size( mem_type_id );
         char * strbuf = (char *)R_alloc(LENGTH(_buf),stsize);
         int z=0;
         int j;
         for (int i=0; i < LENGTH(_buf); i++) {
-            for (j=0; (j < LENGTH(STRING_ELT(_buf,i))) & (j < (stsize-1)); j++) {
+            for (j=0; (j < LENGTH(STRING_ELT(_buf,i))) & (j < stsize); j++) {
                 strbuf[z++] = CHAR(STRING_ELT(_buf,i))[j];
             }
             for (; j < stsize; j++) {
